==> haskell-req-3.13.4-23-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-req.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 req
version:              3.13.4
visibility:           public
id:                   req-3.13.4-DyWJPphJym2FpXfyQ7o9pb
key:                  req-3.13.4-DyWJPphJym2FpXfyQ7o9pb
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/req
synopsis:             HTTP client library
description:          HTTP client library.
category:             Network, Web
abi:                  3af032938b68b6b53a13384d550ffea6
exposed:              True
exposed-modules:      Network.HTTP.Req
import-dirs:          /usr/lib/ghc-9.6.6/site-local/req-3.13.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/req-3.13.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/req-3.13.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-req
hs-libraries:         HSreq-3.13.4-DyWJPphJym2FpXfyQ7o9pb
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    authenticate-oauth-1.7-LVfJbbsaaAM8EUlBSEN0UV base-4.18.2.1
    blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z containers-0.6.7
    crypton-connection-0.4.5-2c10WiKFU3L73agHYaksHE
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc exceptions-0.10.7
    http-api-data-0.6.1-5XEHPNAfLnyD0ajpwpE9eT
    http-client-0.7.19-ITPZXASBEGHLmOi4NfdGY8
    http-client-tls-0.3.6.4-2TpGPIcpPZAJDvilQsJ18b
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    modern-uri-0.3.6.1-IwjiwRk8dF03FTPer57pKX
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 mtl-2.3.1
    retry-0.9.3.1-HEvs5AQWwJi8IsgEJKYYst template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/haskell-req/html/req.haddock
haddock-html:         /usr/share/doc/haskell-req/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-req-3.13.4-24-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-req.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 req
version:              3.13.4
visibility:           public
id:                   req-3.13.4-JjEa1GVDefl9Wlg0cI4xYv
key:                  req-3.13.4-JjEa1GVDefl9Wlg0cI4xYv
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/req
synopsis:             HTTP client library
description:          HTTP client library.
category:             Network, Web
abi:                  997a9738947b7c1ae8f2a4087c5a8f18
exposed:              True
exposed-modules:      Network.HTTP.Req
import-dirs:          /usr/lib/ghc-9.6.6/site-local/req-3.13.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/req-3.13.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/req-3.13.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-req
hs-libraries:         HSreq-3.13.4-JjEa1GVDefl9Wlg0cI4xYv
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    authenticate-oauth-1.7-Q4xD21IK8fI8kc0KhYJUM base-4.18.2.1
    blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv bytestring-0.11.5.3
    case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI containers-0.6.7
    crypton-connection-0.4.5-EMMKhGKvDZ19xloyuzywis
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc exceptions-0.10.7
    http-api-data-0.6.1-6b8SlzeGz22trXyYobem
    http-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
    http-client-tls-0.3.6.4-GXwyMNGv8mPI3u8Rlj5noc
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    modern-uri-0.3.6.1-Fr6OaKthQTjHVJ2Unps2DR
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 mtl-2.3.1
    retry-0.9.3.1-FYTMxXzp6ILABIm5Dm7RjL template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/haskell-req/html/req.haddock
haddock-html:         /usr/share/doc/haskell-req/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
